---
hide:
    - toc
---
# 🇫🇮🇪🇪 Finnic

See the [leaderboard page](/leaderboards) for more information about all the columns.

/// tab | Generative Leaderboard
<iframe title="" aria-label="Table" id="datawrapper-chart-z0Oph" src="https://datawrapper.dwcdn.net/z0Oph" scrolling="no" frameborder="0" style="width: 0; min-width: 100% !important; border: none;" height="838" data-external="1"></iframe><script type="text/javascript">!function(){"use strict";window.addEventListener("message",function(a){if(void 0!==a.data["datawrapper-height"]){var e=document.querySelectorAll("iframe");for(var t in a.data["datawrapper-height"])for(var r,i=0;r=e[i];i++)if(r.contentWindow===a.source){var d=a.data["datawrapper-height"][t]+"px";r.style.height=d}}})}();</script>
///

/// tab | NLU Leaderboard
<iframe title="" aria-label="Table" id="datawrapper-chart-i0AW4" src="https://datawrapper.dwcdn.net/i0AW4" scrolling="no" frameborder="0" style="width: 0; min-width: 100% !important; border: none;" height="824" data-external="1"></iframe><script type="text/javascript">!function(){"use strict";window.addEventListener("message",function(a){if(void 0!==a.data["datawrapper-height"]){var e=document.querySelectorAll("iframe");for(var t in a.data["datawrapper-height"])for(var r,i=0;r=e[i];i++)if(r.contentWindow===a.source){var d=a.data["datawrapper-height"][t]+"px";r.style.height=d}}})}();</script>
///

/// tab | Generative Scatter Plot
<iframe title="Few-shot Performance of Generative Language Models on Finnish Tasks by Model Size" aria-label="Scatter Plot" id="datawrapper-chart-AT7ZK" src="https://datawrapper.dwcdn.net/AT7ZK" scrolling="no" frameborder="0" style="width: 0; min-width: 100% !important; border: none;" height="687" data-external="1"></iframe><script type="text/javascript">!function(){"use strict";window.addEventListener("message",function(a){if(void 0!==a.data["datawrapper-height"]){var e=document.querySelectorAll("iframe");for(var t in a.data["datawrapper-height"])for(var r,i=0;r=e[i];i++)if(r.contentWindow===a.source){var d=a.data["datawrapper-height"][t]+"px";r.style.height=d}}})}();</script>
///

/// tab | NLU Scatter Plot
<iframe title="Few-shot Performance of Language Models on Finnish NLU Tasks by Model Size" aria-label="Scatter Plot" id="datawrapper-chart-BpknI" src="https://datawrapper.dwcdn.net/BpknI" scrolling="no" frameborder="0" style="width: 0; min-width: 100% !important; border: none;" height="687" data-external="1"></iframe><script type="text/javascript">!function(){"use strict";window.addEventListener("message",function(a){if(void 0!==a.data["datawrapper-height"]){var e=document.querySelectorAll("iframe");for(var t in a.data["datawrapper-height"])for(var r,i=0;r=e[i];i++)if(r.contentWindow===a.source){var d=a.data["datawrapper-height"][t]+"px";r.style.height=d}}})}();</script>
///
